==> ikaaro-0.50.3.tar.gz: ikaaro-0.50.3/ui/tiny_mce/plugins/table/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.table_dlg',{
general_tab:"\u4E00\u822C",
advanced_tab:"\u4E0A\u7D1A\u8005\u5411\u3051",
general_props:"\u4E00\u822C",
advanced_props:"\u4E0A\u7D1A\u8005\u5411\u3051",
rowtype:"\u884C",
title:"\u8868\u306E\u633F\u5165/\u7DE8\u96C6",
width:"\u5E45",
height:"\u9AD8\u3055",
cols:"\u5217",
rows:"\u884C",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"\u67A0\u7DDA",
align:"\u914D\u7F6E",
align_default:"\u30C7\u30D5\u30A9\u30EB\u30C8",
align_left:"\u5DE6\u63C3\u3048",
align_right:"\u53F3\u63C3\u3048",
align_middle:"\u4E2D\u592E\u63C3\u3048",
row_title:"\u884C\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
cell_title:"\u30BB\u30EB\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
cell_type:"\u30BB\u30EB\u7A2E\u5225",
valign:"\u5782\u76F4\u65B9\u5411\u306E\u914D\u7F6E",
align_top:"\u4E0A\u63C3\u3048",
align_bottom:"\u4E0B\u63C3\u3048",
bordercolor:"\u67A0\u7DDA\u306E\u8272",
bgcolor:"\u80CC\u666F\u8272",
merge_cells_title:"\u30BB\u30EB\u306E\u7D50\u5408",
id:"ID",
style:"\u30B9\u30BF\u30A4\u30EB",
langdir:"\u6587\u7AE0\u306E\u65B9\u5411",
langcode:"\u8A00\u8A9E\u30B3\u30FC\u30C9",
mime:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306EMIME\u30BF\u30A4\u30D7",
ltr:"\u5DE6\u304B\u3089\u53F3",
rtl:"\u53F3\u304B\u3089\u5DE6",
bgimage:"\u80CC\u666F\u753B\u50CF",
summary:"\u30B5\u30DE\u30EA\u30FC",
td:"\u65E5\u4ED8",
th:"\u30D8\u30C3\u30C0",
cell_cell:"\u9078\u629E\u30BB\u30EB\u306E\u66F4\u65B0",
cell_row:"\u884C\u5185\u306E\u30BB\u30EB\u306E\u66F4\u65B0",
cell_all:"\u5168\u3066\u306E\u30BB\u30EB\u306E\u66F4\u65B0",
row_row:"\u9078\u629E\u884C\u306E\u66F4\u65B0",
row_odd:"\u5947\u6570\u884C\u306E\u66F4\u65B0",
row_even:"\u5076\u6570\u884C\u306E\u66F4\u65B0",
row_all:"\u5168\u3066\u306E\u884C\u306E\u66F4\u65B0",
thead:"\u8868\u30D8\u30C3\u30C0",
tbody:"\u8868\u30DC\u30C7\u30A3",
tfoot:"\u8868\u30D5\u30C3\u30BF",
scope:"\u30B9\u30B3\u30FC\u30D7",
rowgroup:"\u884C\u30B0\u30EB\u30FC\u30D7",
colgroup:"\u5217\u30B0\u30EB\u30FC\u30D7",
col_limit:"\u5217\u306E\u6700\u5927\u6570\u3092\u8D85\u3048\u307E\u3057\u305F\u3002",
row_limit:"\u884C\u306E\u6700\u5927\u6570\u3092\u8D85\u3048\u307E\u3057\u305F\u3002",
cell_limit:"\u30BB\u30EB\u306E\u6700\u5927\u6570\u3092\u8D85\u3048\u307E\u3057\u305F\u3002",
missing_scope:"\u8868\u306E\u30B9\u30B3\u30FC\u30D7\u5C5E\u6027\u3092\u8A2D\u5B9A\u3057\u3066\u3044\u307E\u305B\u3093\u304C\u3088\u308D\u3057\u3044\u3067\u3059\u304B\uFF1F",
caption:"\u8868\u306B\u898B\u51FA\u3057\u3092\u4ED8\u3051\u308B",
frame:"\u30BB\u30EB\u67A0\u7DDA",
frame_none:"\u306A\u3057",
frame_groups:"\u30B0\u30EB\u30FC\u30D7\u6BCE",
frame_rows:"\u884C",
frame_cols:"\u5217",
frame_all:"\u5168\u3066",
rules:"\u8868\u306E\u5916\u67A0",
rules_void:"\u306A\u3057",
rules_above:"\u4E0A",
rules_below:"\u4E0B",
rules_hsides:"\u4E0A\u4E0B",
rules_lhs:"\u5DE6",
rules_rhs:"\u53F3",
rules_vsides:"\u5DE6\u53F3",
rules_box:"\u4E0A\u4E0B\u5DE6\u53F3(box)",
rules_border:"\u4E0A\u4E0B\u5DE6\u53F3(border)"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/table/langs/ja_dlg.js <==
tinyMCE.addI18n('ja.table_dlg',{
general_tab:"\u4E00\u822C",
advanced_tab:"\u4E0A\u7D1A\u8005\u5411\u3051",
general_props:"\u4E00\u822C",
advanced_props:"\u4E0A\u7D1A\u8005\u5411\u3051",
rowtype:"\u884C",
title:"\u8868\u306E\u633F\u5165/\u7DE8\u96C6",
width:"\u5E45",
height:"\u9AD8\u3055",
cols:"\u5217",
rows:"\u884C",
cellspacing:"Cellspacing",
cellpadding:"Cellpadding",
border:"\u67A0\u7DDA",
align:"\u914D\u7F6E",
align_default:"\u30C7\u30D5\u30A9\u30EB\u30C8",
align_left:"\u5DE6\u63C3\u3048",
align_right:"\u53F3\u63C3\u3048",
align_middle:"\u4E2D\u592E\u63C3\u3048",
row_title:"\u884C\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
cell_title:"\u30BB\u30EB\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
cell_type:"\u30BB\u30EB\u7A2E\u5225",
valign:"\u5782\u76F4\u65B9\u5411\u306E\u914D\u7F6E",
align_top:"\u4E0A\u63C3\u3048",
align_bottom:"\u4E0B\u63C3\u3048",
bordercolor:"\u67A0\u7DDA\u306E\u8272",
bgcolor:"\u80CC\u666F\u8272",
merge_cells_title:"\u30BB\u30EB\u306E\u7D50\u5408",
id:"ID\u5C5E\u6027",
style:"style\u5C5E\u6027",
langdir:"\u6587\u7AE0\u306E\u65B9\u5411",
langcode:"\u8A00\u8A9E\u30B3\u30FC\u30C9",
mime:"\u30BF\u30FC\u30B2\u30C3\u30C8\u306EMIME\u30BF\u30A4\u30D7",
ltr:"\u5DE6\u304B\u3089\u53F3",
rtl:"\u53F3\u304B\u3089\u5DE6",
bgimage:"\u80CC\u666F\u753B\u50CF",
summary:"\u30B5\u30DE\u30EA\u30FC",
td:"\u30C7\u30FC\u30BF",
th:"\u30D8\u30C3\u30C0",
cell_cell:"\u9078\u629E\u30BB\u30EB\u306E\u66F4\u65B0",
cell_row:"\u884C\u5185\u306E\u30BB\u30EB\u306E\u66F4\u65B0",
cell_all:"\u5168\u3066\u306E\u30BB\u30EB\u306E\u66F4\u65B0",
row_row:"\u9078\u629E\u884C\u306E\u66F4\u65B0",
row_odd:"\u5947\u6570\u884C\u306E\u66F4\u65B0",
row_even:"\u5076\u6570\u884C\u306E\u66F4\u65B0",
row_all:"\u5168\u3066\u306E\u884C\u306E\u66F4\u65B0",
thead:"\u8868\u30D8\u30C3\u30C0",
tbody:"\u8868\u30DC\u30C7\u30A3",
tfoot:"\u8868\u30D5\u30C3\u30BF",
scope:"\u30B9\u30B3\u30FC\u30D7",
rowgroup:"\u884C\u30B0\u30EB\u30FC\u30D7",
colgroup:"\u5217\u30B0\u30EB\u30FC\u30D7",
col_limit:"\u5217\u306E\u6700\u5927\u6570\u3092\u8D85\u3048\u307E\u3057\u305F\u3002",
row_limit:"\u884C\u306E\u6700\u5927\u6570\u3092\u8D85\u3048\u307E\u3057\u305F\u3002",
cell_limit:"\u30BB\u30EB\u306E\u6700\u5927\u6570\u3092\u8D85\u3048\u307E\u3057\u305F\u3002",
missing_scope:"\u8868\u306E\u30B9\u30B3\u30FC\u30D7\u5C5E\u6027\u3092\u8A2D\u5B9A\u3057\u3066\u3044\u307E\u305B\u3093\u304C\u3088\u308D\u3057\u3044\u3067\u3059\u304B\uFF1F",
caption:"\u8868\u306B\u898B\u51FA\u3057\u3092\u4ED8\u3051\u308B",
frame:"\u30BB\u30EB\u67A0\u7DDA",
frame_none:"\u306A\u3057",
frame_groups:"\u30B0\u30EB\u30FC\u30D7\u6BCE",
frame_rows:"\u884C",
frame_cols:"\u5217",
frame_all:"\u5168\u3066",
rules:"\u8868\u306E\u5916\u67A0",
rules_void:"\u306A\u3057",
rules_above:"\u4E0A",
rules_below:"\u4E0B",
rules_hsides:"\u4E0A\u4E0B",
rules_lhs:"\u5DE6",
rules_rhs:"\u53F3",
rules_vsides:"\u5DE6\u53F3",
rules_box:"\u4E0A\u4E0B\u5DE6\u53F3(box)",
rules_border:"\u4E0A\u4E0B\u5DE6\u53F3(border)"
});
